| Title: | Create AAGI Survey URLs and Analyse AAGI Survey Results |
|---|---|
| Description: | Create 'AAGI' service and support survey URLs interactively or scripted for sharing with partners. |
| Authors: | Rose Megirian [aut], Adam Sparks [aut, cre] (ORCID: <https://orcid.org/0000-0002-0061-8359>), Grains Research and Development Corporation [fnd, cph] (GRDC Project CUR2210-005OPX (AAGI-CU), ROR: <https://ror.org/02xwr1996>) |
| Maintainer: | Adam Sparks <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-05-25 11:52:20 UTC |
| Source: | https://github.com/AAGI-AUS/AAGISurvey |
Create the URL string from user provided values for returning to the user.
build_url( base, support_type, design_type, analysis_type, aagi_node, organisation_type )build_url( base, support_type, design_type, analysis_type, aagi_node, organisation_type )
base |
Character string of base URL. |
support_type |
Character string of support type. |
design_type |
Character string of design type. |
analysis_type |
Character string of analysis type. |
aagi_node |
Character string of AAGI node. |
organisation_type |
Character string of organisation type. |
The full URL string.
build_url( base = "https://curtin.au1.qualtrics.com/jfe/form/SV_eXLvfgMz58RktQa", support_type = "S_D", design_type = "D_SP", analysis_type = "A_BIO", aagi_node = "CU", organisation_type = "O_ACA" )build_url( base = "https://curtin.au1.qualtrics.com/jfe/form/SV_eXLvfgMz58RktQa", support_type = "S_D", design_type = "D_SP", analysis_type = "A_BIO", aagi_node = "CU", organisation_type = "O_ACA" )
This function is designed to be used each time you need to generate a survey URL for requesting feedback from a partner. It embeds information already known by the team so that respondents do not need to provide it. This includes the type of support provided, the output delivered, the AAGI node that delivered the work, and the organisation type of the partner. These details are included as metadata within the URL so that the survey platform can automatically link each respondents feedback to the relevant contextual information.
create_survey_url( support_type = NULL, design_type = NULL, analysis_type = NULL, aagi_node = NULL, organisation_type = NULL )create_survey_url( support_type = NULL, design_type = NULL, analysis_type = NULL, aagi_node = NULL, organisation_type = NULL )
support_type |
Character string specifying the type of support being evaluated. You must choose one. Options are:
|
design_type |
Character string specifying the type of experimental
design (required if "S_D" is selected for
|
analysis_type |
Character string of analysis type. Required if
"S_A" is selected for
|
aagi_node |
Character string of AAGI node. Options are:
|
organisation_type |
Character string of organisation type. Options are:
|
You can use the function in two ways. You can supply all required arguments directly in your script, or you can run the function in interactive mode. In interactive use, the function presents a menu in the console that guides you through each field.
Once the relevant information has been provided, the function returns the completed survey URL, prints a short summary of the details you supplied and copies the URL to your operating system clipboard for inclusion in an email or other communication.
Rose Megirian, [email protected] and Adam H. Sparks, [email protected]
# create a survey URL for # - a small plot trial design # - for a government agency or department # - performed by Curtin node create_survey_url( support_type = "S_D", design_type = "D_SP", aagi_node = "CU", organisation_type = "O_GOV" ) # create a survey URL for # - a bioinformatics analysis # - for an academic institution # - performed by Adelaide University node create_survey_url( support_type = "S_A", analysis_type = "A_BIO", aagi_node = "AU", organisation_type = "O_ACA" )# create a survey URL for # - a small plot trial design # - for a government agency or department # - performed by Curtin node create_survey_url( support_type = "S_D", design_type = "D_SP", aagi_node = "CU", organisation_type = "O_GOV" ) # create a survey URL for # - a bioinformatics analysis # - for an academic institution # - performed by Adelaide University node create_survey_url( support_type = "S_A", analysis_type = "A_BIO", aagi_node = "AU", organisation_type = "O_ACA" )